@@ -3,7 +3,7 @@
 # Generate Client
 rm src/apis src/models docs -rf
 
-java -jar ../foo-openapi-generator/modules/openapi-generator-cli/target/openapi-generator-cli.jar generate \
+java -jar ./openapi-generator-cli.jar generate \
 -g rust \
 --additional-properties=packageName=vrchatapi,supportAsync=false \
 --git-user-id=vrchatapi \
@@ -11,6 +11,7 @@ java -jar ../foo-openapi-generator/modules/openapi-generator-cli/target/openapi-
 -o . \
 -i https://vrchatapi.github.io/specification/openapi.yaml \
 --http-user-agent="vrchatapi-rust"
+#--global-property debugOperations=true
 
 # Add license and description to Cargo.toml
 sed -i '/^edition = "2018"/i license = "MIT"' Cargo.toml
