@@ -1,11 +1,23 @@
+pub mod add_favorite_request;
+pub use self::add_favorite_request::AddFavoriteRequest;
 pub mod api_config;
 pub use self::api_config::ApiConfig;
 pub mod api_event_config;
 pub use self::api_event_config::ApiEventConfig;
+pub mod api_health;
+pub use self::api_health::ApiHealth;
 pub mod avatar;
 pub use self::avatar::Avatar;
 pub mod avatar_unity_package_url_object;
 pub use self::avatar_unity_package_url_object::AvatarUnityPackageUrlObject;
+pub mod create_avatar_request;
+pub use self::create_avatar_request::CreateAvatarRequest;
+pub mod create_file_request;
+pub use self::create_file_request::CreateFileRequest;
+pub mod create_file_version_request;
+pub use self::create_file_version_request::CreateFileVersionRequest;
+pub mod create_world_request;
+pub use self::create_world_request::CreateWorldRequest;
 pub mod current_user;
 pub use self::current_user::CurrentUser;
 pub mod deployment_group;
@@ -32,54 +44,18 @@ pub mod file_data;
 pub use self::file_data::FileData;
 pub mod file_status;
 pub use self::file_status::FileStatus;
+pub mod file_upload_url;
+pub use self::file_upload_url::FileUploadUrl;
 pub mod file_version;
 pub use self::file_version::FileVersion;
+pub mod file_version_upload_status;
+pub use self::file_version_upload_status::FileVersionUploadStatus;
+pub mod finish_file_data_upload_request;
+pub use self::finish_file_data_upload_request::FinishFileDataUploadRequest;
 pub mod friend_status;
 pub use self::friend_status::FriendStatus;
-pub mod inline_object;
-pub use self::inline_object::InlineObject;
-pub mod inline_object_1;
-pub use self::inline_object_1::InlineObject1;
-pub mod inline_object_10;
-pub use self::inline_object_10::InlineObject10;
-pub mod inline_object_11;
-pub use self::inline_object_11::InlineObject11;
-pub mod inline_object_12;
-pub use self::inline_object_12::InlineObject12;
-pub mod inline_object_13;
-pub use self::inline_object_13::InlineObject13;
-pub mod inline_object_2;
-pub use self::inline_object_2::InlineObject2;
-pub mod inline_object_3;
-pub use self::inline_object_3::InlineObject3;
-pub mod inline_object_4;
-pub use self::inline_object_4::InlineObject4;
-pub mod inline_object_5;
-pub use self::inline_object_5::InlineObject5;
-pub mod inline_object_6;
-pub use self::inline_object_6::InlineObject6;
-pub mod inline_object_7;
-pub use self::inline_object_7::InlineObject7;
-pub mod inline_object_8;
-pub use self::inline_object_8::InlineObject8;
-pub mod inline_object_9;
-pub use self::inline_object_9::InlineObject9;
-pub mod inline_response_200;
-pub use self::inline_response_200::InlineResponse200;
-pub mod inline_response_200_1;
-pub use self::inline_response_200_1::InlineResponse2001;
-pub mod inline_response_200_2;
-pub use self::inline_response_200_2::InlineResponse2002;
-pub mod inline_response_200_3;
-pub use self::inline_response_200_3::InlineResponse2003;
-pub mod inline_response_200_4;
-pub use self::inline_response_200_4::InlineResponse2004;
-pub mod inline_response_200_5;
-pub use self::inline_response_200_5::InlineResponse2005;
-pub mod inline_response_200_6;
-pub use self::inline_response_200_6::InlineResponse2006;
-pub mod inline_response_400;
-pub use self::inline_response_400::InlineResponse400;
+pub mod inline_response_404;
+pub use self::inline_response_404::InlineResponse404;
 pub mod instance;
 pub use self::instance::Instance;
 pub mod instance_platforms;
@@ -100,6 +76,8 @@ pub mod limited_world;
 pub use self::limited_world::LimitedWorld;
 pub mod mime_type;
 pub use self::mime_type::MimeType;
+pub mod moderate_user_request;
+pub use self::moderate_user_request::ModerateUserRequest;
 pub mod notification;
 pub use self::notification::Notification;
 pub mod notification_type;
@@ -120,8 +98,20 @@ pub mod response;
 pub use self::response::Response;
 pub mod success;
 pub use self::success::Success;
+pub mod two_factor_auth_code;
+pub use self::two_factor_auth_code::TwoFactorAuthCode;
 pub mod unity_package;
 pub use self::unity_package::UnityPackage;
+pub mod update_avatar_request;
+pub use self::update_avatar_request::UpdateAvatarRequest;
+pub mod update_favorite_group_request;
+pub use self::update_favorite_group_request::UpdateFavoriteGroupRequest;
+pub mod update_invite_message_request;
+pub use self::update_invite_message_request::UpdateInviteMessageRequest;
+pub mod update_user_request;
+pub use self::update_user_request::UpdateUserRequest;
+pub mod update_world_request;
+pub use self::update_world_request::UpdateWorldRequest;
 pub mod user;
 pub use self::user::User;
 pub mod user_exists;
@@ -130,5 +120,13 @@ pub mod user_state;
 pub use self::user_state::UserState;
 pub mod user_status;
 pub use self::user_status::UserStatus;
+pub mod verify2_fa_result;
+pub use self::verify2_fa_result::Verify2FaResult;
+pub mod verify_auth_token_result;
+pub use self::verify_auth_token_result::VerifyAuthTokenResult;
 pub mod world;
 pub use self::world::World;
+pub mod world_metadata;
+pub use self::world_metadata::WorldMetadata;
+pub mod world_publish_status;
+pub use self::world_publish_status::WorldPublishStatus;
